/**
 * Represents an individual service with basic information necessary for status tracking.
 * @public
 */
export interface SystemHealthAlertsServiceItem {
    tag: string;
    name: string;
    isConnected: boolean;
}
/**
 * Represents the available types of service status messages.
 * @public
 */
export type SystemHealthAlertsServiceItemState = 'restored' | 'failed';
/**
 * Parameters for template functions used in service status messaging, providing hooks for restoration and failure handling.
 * @public
 */
export interface ServiceStatusGetTemplateParmas {
    restored: (prefix: string, item: SystemHealthAlertsServiceItem) => any;
    failed: (prefix: string, item: SystemHealthAlertsServiceItem) => any;
}
/**
 * Configuration options for service status, including behavior around automatic closure and timeouts.
 * @public
 */
export interface ServicesStatusConfig {
    autoClose: boolean;
    closeTimeout: number;
    maxMessages: number;
}
/**
 * Represents the server item with basic information necessary for status tracking.
 * @internal
 */
export interface SystemHealthAlertsServiceSystemStatusItem {
    isConnected: boolean;
    lastError: number;
    lastUpdated: number;
    name: string;
    sourceRef: string[];
}
/**
 * Type helper for the service status helper text generation.
 * @internal
 */
export type SystemHealthAlertsServiceHelperText = 'title' | 'message';
//# sourceMappingURL=main.types.d.ts.map